class CRoman {

	public final static int MAX_VALUE = 3999;

	// Fehlerkonstanten
	public static final int NO_ERROR = 0;
	public static final int INVALID_STRING_ERROR = 1;
	public static final int INVALID_VALUE_ERROR = 2;

	// globale Fehlervariable
	protected static int error = CRoman.NO_ERROR;

	// interne Datenstruktur zur Speicherung des Wertes
	private int value;

	// erzeugt eine roemische Zahl mit dem angegebenen Wert
	// Fehler, wenn v <= 0 oder v > MAX_VALUE
	public CRoman(int v) {
		if (v > 0 && v <= CRoman.MAX_VALUE) {
			this.value = v;
			CRoman.error = CRoman.NO_ERROR;
		} else {
			CRoman.error = CRoman.INVALID_VALUE_ERROR;
		}
	}

	// erzeugt eine roemische Zahl mit dem durch den String repraesentierten
	// Wert
	// Fehler, wenn der String keine gueltige roemische Zahl darstellt
	public CRoman(String str) {
		if (CRoman.check(str)) {
			this.value = CRoman.convertRomanToInt(str);
			CRoman.error = CRoman.NO_ERROR;
		} else {
			CRoman.error = CRoman.INVALID_STRING_ERROR;
		}
	}

	// addiert die roemische Zahl zur aufgerufenen roemischen Zahl
	public void add(CRoman roman) {
		if (this.value + roman.value <= CRoman.MAX_VALUE) {
			this.value += roman.value;
			CRoman.error = CRoman.NO_ERROR;
		} else {
			CRoman.error = CRoman.INVALID_VALUE_ERROR;
		}
	}

	@Override
	public String toString() {
		return CRoman.convertIntToRoman(this.value);
	}

	// interne Datenstruktur fuer Umrechnungszwecke
	static String symbol = "IVXLCDM";
	static int[] wert = { 1, 5, 10, 50, 100, 500, 1000 };

	// ueberprueft, ob der String eine gueltige roemische Zahl darstellt
	private static boolean check(String str) {
		return true; // todo (muss hier gueltig sein)
	}

	// liefert den int-Wert, den der String (gueltige roemische Zahl!) darstellt
	private static int convertRomanToInt(String roman) {
		int value = 0;
		// String der Reihe nach durcharbeiten
		for (int i = 0; i < roman.length(); i++) {
			// Index bestimmen
			int index1 = CRoman.symbol.indexOf(roman.charAt(i));
			if (i + 1 < roman.length()) { // es folgen weitere Symbole
				int index2 = CRoman.symbol.indexOf(roman.charAt(i + 1));
				if (index1 < index2) { // Differenz bilden und addieren
					value = value + CRoman.wert[index2] - CRoman.wert[index1];
					i++;
				} else { // addieren
					value = value + CRoman.wert[index1];
				}
			} else { // letztes Symbol
				value = value + CRoman.wert[index1];
			}
		}
		return value;
	}

	// interne Datenstruktur fuer Umrechnungszwecke
	static String symbols[][] = {
			// Symbole fuer 1-9
			{ "", "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX" },
			// Symbole fuer 10-90
			{ "", "X", "XX", "XXX", "XL", "L", "LX", "LXX", "LXXX", "XC" },
			// Symbole fuer 100-900
			{ "", "C", "CC", "CCC", "CD", "D", "DC", "DCC", "DCCC", "CM" },
			// Symbol fuer 1000
			{ "", "M", "MM", "MMM" } };

	// wandelt den uebergebenen int-Wert in eine Darstellung als rmische Zahl
	// um
	private static String convertIntToRoman(int value) {
		String roman = new String("");
		int potenz = 0;
		while (value > 0) {
			// bestimme letzte Ziffer
			int ziffer = value % 10;
			// erweitere die Roemische Zahl entsprechend der Ziffer und der
			// aktuellen Stelligkeit
			roman = CRoman.symbols[potenz][ziffer] + roman;
			// erhoehe Stelligkeit
			potenz++;
			// kuerze value um eine Stelle
			value = value / 10;
		}
		return roman;
	}
}

public class UE21Aufgabe16 {

	// Testprogramm
	public static void main(String[] args) {
		int zahl = IO.readInt("int-Zahl: ");
		CRoman roman1 = new CRoman(zahl);
		if (CRoman.error == CRoman.INVALID_VALUE_ERROR) {
			System.out.println("ungueltiger Wert");
		} else {
			String str = IO.readString("roemische Zahl: ");
			CRoman roman2 = new CRoman(str);
			if (CRoman.error == CRoman.INVALID_STRING_ERROR) {
				System.out.println("ungueltiger String");
			} else {
				roman1.add(roman2);
				if (CRoman.error == CRoman.INVALID_VALUE_ERROR) {
					System.out.println("zu grosser Wert");
				} else {
					System.out.println(roman1);
				}
			}
		}
	}
}

